@@ -361,7 +361,7 @@ def summarize_pae_pdf(df, threshold, rankby):
 #     return view
 
 def write_top(df, threshold, rankby):
-    
+
     if threshold == 0:
         basename = "Results"
     else:
@@ -369,20 +369,20 @@ def write_top(df, threshold, rankby):
         
     excelname = basename + ".xlsx"
     csvname = basename + ".csv"
+
+    print("\n>> Writing " + excelname + " and " + csvname)
     
     with pd.ExcelWriter(excelname) as writer:  
         df[df[rankby]>threshold].to_excel(writer)
         
     df.to_csv(csvname)
-    
-    print("\n>> Wrote " + excelname + " and " + csvname)
         
         
 def write_modelpngs(df, threshold, rankby, overwrite=False):
 
     print("\n>> Writing model snapshots...")
 
-    pymol.finish_launching(['pymol', '-qc']) #-Q will suppress render outputs too
+    pymol.finish_launching(['pymol', '-qc']) #-Q will suppress render outputs too if you want
 
     total=0
 
@@ -427,8 +427,6 @@ def write_modelpngs(df, threshold, rankby, overwrite=False):
         
         total+=1
         
-    #print("\n>> Wrote png-snapshots for " + str(total) + " pdbs.")
-        
 def waitfor(filename):
     pngexists=False
     tic = time.perf_counter()
